@@ -16,15 +16,22 @@ use std::{
 };
 use std::{fmt::Write, sync::LazyLock};
 
-use crate::{audit::AuditInput, models::AsDocument, registry::input::InputError};
+use crate::{audit::AuditInput, models::AsDocument, registry::input::CollectionError};
+
+pub(crate) static ZIZMOR_AGENT: &str = concat!("zizmor/", env!("CARGO_PKG_VERSION"));
+
+pub(crate) static WORKFLOW_VALIDATOR: LazyLock<Validator> = LazyLock::new(|| {
+    validator_for(&serde_json::from_str(include_str!("./data/github-workflow.json")).unwrap())
+        .unwrap()
+});
 
 pub(crate) static ACTION_VALIDATOR: LazyLock<Validator> = LazyLock::new(|| {
     validator_for(&serde_json::from_str(include_str!("./data/github-action.json")).unwrap())
         .unwrap()
 });
 
-pub(crate) static WORKFLOW_VALIDATOR: LazyLock<Validator> = LazyLock::new(|| {
-    validator_for(&serde_json::from_str(include_str!("./data/github-workflow.json")).unwrap())
+pub(crate) static DEPENDABOT_VALIDATOR: LazyLock<Validator> = LazyLock::new(|| {
+    validator_for(&serde_json::from_str(include_str!("./data/dependabot-2.0.json")).unwrap())
         .unwrap()
 });
 
@@ -322,7 +329,7 @@ fn parse_validation_errors(errors: VecDeque<OutputUnit<ErrorDescription>>) -> Er
 pub(crate) fn from_str_with_validation<'de, T>(
     contents: &'de str,
     validator: &'static Validator,
-) -> Result<T, InputError>
+) -> Result<T, CollectionError>
 where
     T: serde::Deserialize<'de>,
 {
@@ -356,11 +363,13 @@ where
                 Ok(raw_value) => match validator.apply(&raw_value).basic() {
                     Valid(_) => Err(e)
                         .context("this suggests a bug in zizmor; please report it!")
-                        .map_err(InputError::Model),
-                    Invalid(errors) => Err(InputError::Schema(parse_validation_errors(errors))),
+                        .map_err(CollectionError::Model),
+                    Invalid(errors) => {
+                        Err(CollectionError::Schema(parse_validation_errors(errors)))
+                    }
                 },
                 // Syntax error.
-                Err(e) => Err(InputError::Syntax(e.into())),
+                Err(e) => Err(CollectionError::Syntax(e.into())),
             }
         }
     }
@@ -634,6 +643,26 @@ impl SpannedQuery {
     }
 }
 
+pub(crate) mod once {
+    macro_rules! once {
+        ($expression:expr) => {{
+            static ONCE: std::sync::Once = std::sync::Once::new();
+            ONCE.call_once(|| {
+                $expression;
+            });
+        }};
+    }
+
+    macro_rules! warn_once {
+        ($($arg:tt)+) => ({
+            crate::utils::once::once!(tracing::warn!($($arg)+))
+        });
+    }
+
+    pub(crate) use once;
+    pub(crate) use warn_once;
+}
+
 #[cfg(test)]
 mod tests {
     use anyhow::Result;
